@@ -115,12 +115,12 @@ class ElasticTranscoderClient(BaseClient):
         self,
         *,
         PipelineId: str,
-        Input: "JobInputTypeDef" = ...,
-        Inputs: Sequence["JobInputTypeDef"] = ...,
-        Output: "CreateJobOutputTypeDef" = ...,
-        Outputs: Sequence["CreateJobOutputTypeDef"] = ...,
+        Input: JobInputTypeDef = ...,
+        Inputs: Sequence[JobInputTypeDef] = ...,
+        Output: CreateJobOutputTypeDef = ...,
+        Outputs: Sequence[CreateJobOutputTypeDef] = ...,
         OutputKeyPrefix: str = ...,
-        Playlists: Sequence["CreateJobPlaylistTypeDef"] = ...,
+        Playlists: Sequence[CreateJobPlaylistTypeDef] = ...,
         UserMetadata: Mapping[str, str] = ...
     ) -> CreateJobResponseTypeDef:
         """
@@ -139,9 +139,9 @@ class ElasticTranscoderClient(BaseClient):
         Role: str,
         OutputBucket: str = ...,
         AwsKmsKeyArn: str = ...,
-        Notifications: "NotificationsTypeDef" = ...,
-        ContentConfig: "PipelineOutputConfigTypeDef" = ...,
-        ThumbnailConfig: "PipelineOutputConfigTypeDef" = ...
+        Notifications: NotificationsTypeDef = ...,
+        ContentConfig: PipelineOutputConfigTypeDef = ...,
+        ThumbnailConfig: PipelineOutputConfigTypeDef = ...
     ) -> CreatePipelineResponseTypeDef:
         """
         The CreatePipeline operation creates a pipeline with settings that you specify.
@@ -156,9 +156,9 @@ class ElasticTranscoderClient(BaseClient):
         Name: str,
         Container: str,
         Description: str = ...,
-        Video: "VideoParametersTypeDef" = ...,
-        Audio: "AudioParametersTypeDef" = ...,
-        Thumbnails: "ThumbnailsTypeDef" = ...
+        Video: VideoParametersTypeDef = ...,
+        Audio: AudioParametersTypeDef = ...,
+        Thumbnails: ThumbnailsTypeDef = ...
     ) -> CreatePresetResponseTypeDef:
         """
         The CreatePreset operation creates a preset with settings that you specify.
@@ -282,9 +282,9 @@ class ElasticTranscoderClient(BaseClient):
         InputBucket: str = ...,
         Role: str = ...,
         AwsKmsKeyArn: str = ...,
-        Notifications: "NotificationsTypeDef" = ...,
-        ContentConfig: "PipelineOutputConfigTypeDef" = ...,
-        ThumbnailConfig: "PipelineOutputConfigTypeDef" = ...
+        Notifications: NotificationsTypeDef = ...,
+        ContentConfig: PipelineOutputConfigTypeDef = ...,
+        ThumbnailConfig: PipelineOutputConfigTypeDef = ...
     ) -> UpdatePipelineResponseTypeDef:
         """
         Use the `UpdatePipeline` operation to update settings for a pipeline.
@@ -294,7 +294,7 @@ class ElasticTranscoderClient(BaseClient):
         """
 
     def update_pipeline_notifications(
-        self, *, Id: str, Notifications: "NotificationsTypeDef"
+        self, *, Id: str, Notifications: NotificationsTypeDef
     ) -> UpdatePipelineNotificationsResponseTypeDef:
         """
         With the UpdatePipelineNotifications operation, you can update Amazon Simple
