@@ -67,7 +67,7 @@ class ListJobsByPipelinePaginator(Boto3Paginator):
         *,
         PipelineId: str,
         Ascending: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListJobsByPipelineResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline.paginate)
@@ -82,7 +82,7 @@ class ListJobsByStatusPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, Status: str, Ascending: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, Status: str, Ascending: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListJobsByStatusResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus.paginate)
@@ -97,7 +97,7 @@ class ListPipelinesPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, Ascending: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, Ascending: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListPipelinesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines.paginate)
@@ -112,7 +112,7 @@ class ListPresetsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, Ascending: str = ..., PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, Ascending: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListPresetsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets.paginate)
