@@ -32,7 +32,7 @@ class JobCompleteWaiter(Boto3Waiter):
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters/#jobcompletewaiter)
     """
 
-    def wait(self, *, Id: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
+    def wait(self, *, Id: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.JobComplete.wait)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters/#jobcompletewaiter)
